@@ -474,6 +474,26 @@ def delete(*args, **kwargs):
     return con.delete(*args, **kwargs)
 
 
+def get_timeout(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.get_timeout(*args, **kwargs)
+
+
+def set_timeout(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.set_timeout(*args, **kwargs)
+
+
+def get_max_retries(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.get_max_retries(*args, **kwargs)
+
+
+def set_max_retries(*args, **kwargs):
+    con = get_server_api_connection()
+    return con.set_max_retries(*args, **kwargs)
+
+
 def get_event(*args, **kwargs):
     con = get_server_api_connection()
     return con.get_event(*args, **kwargs)
@@ -733,12 +753,12 @@ def get_secrets(*args, **kwargs):
 
 def get_secret(*args, **kwargs):
     con = get_server_api_connection()
-    return con.delete_secret(*args, **kwargs)
+    return con.get_secret(*args, **kwargs)
 
 
 def save_secret(*args, **kwargs):
     con = get_server_api_connection()
-    return con.delete_secret(*args, **kwargs)
+    return con.save_secret(*args, **kwargs)
 
 
 def delete_secret(*args, **kwargs):
